get_drop: Spamhaus Don't Route Or Peer List

Description Usage Details Note References

Description

Retrieves the Spamhaus Don't Route Or Peer List

Usage

1

Details

The DROP list will not include any IP address space under the control of any legitimate network - even if being used by "the spammers from hell". DROP will only include netblocks allocated directly by an established Regional Internet Registry (RIR) or National Internet Registry (NIR) such as ARIN, RIPE, AFRINIC, APNIC, LACNIC or KRNIC or direct RIR allocations.

Note

This function is "memoised" because the DROP list changes quite slowly. There is no need to update cached data more than once per hour, in fact once per day is more than enough in most cases. Automated downloads must be at least one hour apart. Excessive downloads may result in your IP being firewalled from the Spamhaus website.

If you are using this from a long-running R session and need to fetch the list, use the clear_drops() function to clear the cache of all "DROP" get functions.

References

https://www.spamhaus.org/drop/; https://www.spamhaus.org/faq/section/


hrbrmstr/hormel documentation built on May 12, 2019, 5:45 a.m.