Description Usage Details Note References
Retrieves the Spamhaus Don't Route Or Peer List
1 | get_drop()
|
The DROP list will not include any IP address space under the control of any legitimate network - even if being used by "the spammers from hell". DROP will only include netblocks allocated directly by an established Regional Internet Registry (RIR) or National Internet Registry (NIR) such as ARIN, RIPE, AFRINIC, APNIC, LACNIC or KRNIC or direct RIR allocations.
This function is "memoised" because the DROP list changes quite slowly.
There is no need to update cached data more than once per hour,
in fact once per day is more than enough in most cases. Automated downloads
must be at least one hour apart. Excessive downloads may result in your IP
being firewalled from the Spamhaus website.
If you are using this from
a long-running R session and need to fetch the list, use the clear_drops()
function to clear the cache of all "DROP" get functions.
https://www.spamhaus.org/drop/; https://www.spamhaus.org/faq/section/
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.